summaryrefslogtreecommitdiffstats
path: root/korganizer/korganizer.h
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/korganizer.h')
-rw-r--r--korganizer/korganizer.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/korganizer/korganizer.h b/korganizer/korganizer.h
index e43c06a8..b4c2e9b2 100644
--- a/korganizer/korganizer.h
+++ b/korganizer/korganizer.h
@@ -104,7 +104,7 @@ class KOrganizer : public KPartsMainWindow, public KOrgMainWindow
protected slots:
/** using the KConfig associated with the kapp variable, read in the
* settings from the config file.
*/
void readSettings();
@@ -128,8 +128,8 @@ class KOrganizer : public KPartsMainWindow, public KOrgMainWindow
bool queryExit();
/* Session management */
- void saveProperties( KConfig * );
- void readProperties( KConfig * );
+ void saveProperties( TDEConfig * );
+ void readProperties( TDEConfig * );
private:
CalendarView *mCalendarView; // Main view widget
@@ -104,7 +104,7 @@ class KOrganizer : public KPartsMainWindow, public KOrgMainWindow
protected slots:
- /** using the KConfig associated with the kapp variable, read in the
+ /** using the TDEConfig associated with the kapp variable, read in the
* settings from the config file.
*/